aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorSergey Poznyakoff <gray@gnu.org.ua>2016-01-23 22:22:26 +0200
committerSergey Poznyakoff <gray@gnu.org.ua>2016-01-23 22:34:17 +0200
commit6889d23af2aa8a4436378b2cd78b0e71a0992eb5 (patch)
tree685d61710a1f921c5d893f1f3b215186f71340bf
parentb946286617a36e74b5ee6efd09930ed18683afd7 (diff)
downloadvmod-variable-6889d23af2aa8a4436378b2cd78b0e71a0992eb5.tar.gz
vmod-variable-6889d23af2aa8a4436378b2cd78b0e71a0992eb5.tar.bz2
Change versioning.
* .gitmodules: New file. * acvmod: New submodule. * bootstrap: Update. * Makefile.am (ACLOCAL_AMFLAGS): Add acvmod * configure.ac: Use AM_VARNISHAPI instead of inlining the related code. Enable silent rules. Set version number 1.0.90-4.1.0 * src/Makefile.am: Enable silent rules. * tests/Makefile.am: Likewise. * src/variable.vcc: Update copyright year. * src/variable.c: Fix copyright statement. * NEWS: Update.
-rw-r--r--.gitmodules3
-rw-r--r--Makefile.am4
-rw-r--r--NEWS11
m---------acvmod0
-rwxr-xr-xbootstrap2
-rw-r--r--configure.ac99
-rw-r--r--src/Makefile.am4
-rw-r--r--src/variable.c10
-rw-r--r--src/variable.vcc2
-rw-r--r--tests/Makefile.am10
10 files changed, 34 insertions, 111 deletions
diff --git a/.gitmodules b/.gitmodules
new file mode 100644
index 0000000..00ae21c
--- /dev/null
+++ b/.gitmodules
@@ -0,0 +1,3 @@
+[submodule "acvmod"]
+ path = acvmod
+ url = git://git.gnu.org.ua/acvmod.git
diff --git a/Makefile.am b/Makefile.am
index 4111605..9afba47 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -1,3 +1,3 @@
# This file is part of vmod-variable
-# Copyright (C) 2013-2014 Sergey Poznyakoff
+# Copyright (C) 2013-2016 Sergey Poznyakoff
#
@@ -15,3 +15,3 @@
# along with vmod-variable. If not, see <http://www.gnu.org/licenses/>.
-ACLOCAL_AMFLAGS = -I m4
+ACLOCAL_AMFLAGS = -I m4 -I acvmod
diff --git a/NEWS b/NEWS
index c0d662a..c0aa244 100644
--- a/NEWS
+++ b/NEWS
@@ -1,2 +1,2 @@
-vmod-variable -- history of user-visible changes. 2016-01-15
+vmod-variable -- history of user-visible changes. 2016-01-23
Copyright (C) 2015-2016 Sergey Poznyakoff
@@ -7,5 +7,10 @@ Please send vmod-variable bug reports to <gray@gnu.org>
-Version 1.0.90, (Git)
+Version 1.0.90-4.1.0, (Git)
-Fix coredumps.
+* Versioning changes
+
+Starting with this release, the version number includes version
+of Varnish API the release was designed for.
+
+* Support for Varnish 4,1
diff --git a/acvmod b/acvmod
new file mode 160000
+Subproject f064cf4d7aa1ead1f8607b8b72baf883f015ffc
diff --git a/bootstrap b/bootstrap
index 89ccf31..ea0a965 100755
--- a/bootstrap
+++ b/bootstrap
@@ -6,2 +6,4 @@ done
test -f ChangeLog || touch ChangeLog
+git submodule init
+git submodule update
autoreconf -f -i -s
diff --git a/configure.ac b/configure.ac
index 4f328e7..ca5c8f7 100644
--- a/configure.ac
+++ b/configure.ac
@@ -16,3 +16,3 @@
AC_PREREQ(2.69)
-AC_INIT([vmod-variable], [1.0.90], [gray@gnu.org])
+AC_INIT([vmod-variable], [1.0.90-4.1.0], [gray@gnu.org])
AC_CONFIG_AUX_DIR([build-aux])
@@ -25,3 +25,4 @@ AC_LANG(C)
-AM_INIT_AUTOMAKE([1.14 gnu tar-ustar])
+AM_INIT_AUTOMAKE([1.14 gnu tar-ustar silent-rules])
+AM_SILENT_RULES([yes])
@@ -31,3 +32,3 @@ AC_PROG_CC_STDC
if test "x$ac_cv_prog_cc_c99" = xno; then
- AC_MSG_ERROR([could not find a C99 compatible compiler])
+ AC_MSG_ERROR([could not find a C99 compatible compiler])
fi
@@ -39,5 +40,2 @@ AC_PROG_MAKE_SET
-# Check for pkg-config
-PKG_PROG_PKG_CONFIG
-
# Checks for header files.
@@ -53,89 +51,4 @@ AC_CHECK_LIB(pcre, pcre_compile,,
-# Check for python
-AC_CHECK_PROGS(PYTHON, [python], [
- AC_MSG_ERROR([python is not found.])])
-
-# Varnish source tree
-AC_ARG_VAR([VARNISHSRC], [path to Varnish source tree])
-AC_ARG_WITH([varnish-source],
- AC_HELP_STRING([--with-varnish-source=DIR],
- [Varnish sources are located in DIR]),
- [VARNISHSRC=$withval])
-
-if test -z "$VARNISHSRC"; then
- AC_MSG_ERROR([no Varnish source tree specified])
-fi
-case "$VARNISHSRC" in
-/*) ;;
-*) AC_MSG_ERROR([varnish source path must be absolute pathname])
-esac
-
-VARNISHSRC=`cd $VARNISHSRC && pwd`
-
-# pkg-config
-PKG_PROG_PKG_CONFIG
-PKG_CHECK_MODULES([libvarnishapi], [varnishapi])
-
-varnishapi_version() {
- VARNISHAPI_MAJOR=$1
- VARNISHAPI_MINOR=$2
- VARNISHAPI_PATCH=$3
-}
-
-v=$($PKG_CONFIG --modversion varnishapi)
-if test -n "$v"; then
- save_IFS=$IFS
- IFS='.'
- varnishapi_version $v
- IFS=$save_IFS
-else
- AC_MSG_ERROR([unknown varnishapi version])
-fi
-
-if test $VARNISHAPI_MAJOR -ne 4; then
- AC_MSG_ERROR([unsupported varnishapi version])
-fi
-
-case $VARNISHAPI_MINOR in
-0) AC_MSG_ERROR([unsupported varnishapi version]);;
-1) ;;
-*) AC_MSG_WARN([varnishapi minor version probably unsupported])
-esac
-
-# Check that varnishtest is built in the varnish source directory
-AC_CHECK_FILE([$VARNISHSRC/bin/varnishtest/varnishtest],
- [],
- [AC_MSG_FAILURE([cannot find "$VARNISHSRC/bin/varnishtest/varnishtest". Please build your varnish source directory])]
-)
-
-# vmod installation dir
-AC_ARG_VAR([VMODDIR], [vmod installation directory])
-AC_ARG_WITH([vmoddir],
- AC_HELP_STRING([--with-vmoddir=DIR],
- [install modules to DIR]),
- [case "$withval" in
- /*) VMODDIR=$withval;;
- no) unset VMODDIR;;
- *) AC_MSG_ERROR([argument to --with-vmoddir must be absolute pathname])
- esac],[VMODDIR=$($PKG_CONFIG --variable=vmoddir varnishapi)
- if test -z "$VMODDIR"; then
- AC_MSG_FAILURE([cannot determine vmod installation directory])
- fi])
-
-
-if test -z "$VMODDIR"; then
- VMODDIR='$(libdir)/varnish/mods'
-fi
-
-AC_CONFIG_COMMANDS([status],[
-delim="-------------------------------------------------------------------"
-echo ""
-echo $delim
-echo "Building for Varnish version $VARNISHAPI_MAJOR.$VARNISHAPI_MINOR"
-echo $delim
-],
-[VARNISHAPI_MAJOR=$VARNISHAPI_MAJOR
-VARNISHAPI_MINOR=$VARNISHAPI_MINOR
-])
-
+AM_VARNISHAPI
+
AC_CONFIG_TESTDIR(tests)
diff --git a/src/Makefile.am b/src/Makefile.am
index 81c5b4e..5396773 100644
--- a/src/Makefile.am
+++ b/src/Makefile.am
@@ -1,3 +1,3 @@
# This file is part of vmod-variable
-# Copyright (C) 2015 Sergey Poznyakoff
+# Copyright (C) 2015, 2016 Sergey Poznyakoff
#
@@ -45,3 +45,3 @@ vccfile = $(top_srcdir)/src/variable.vcc
vcc_if.c vcc_if.h: $(vmodtool) $(vccfile)
- @PYTHON@ $(vmodtool) $(vmodtoolargs) $(vccfile)
+ $(AM_V_GEN)$(PYTHON) $(vmodtool) $(vmodtoolargs) $(vccfile)
diff --git a/src/variable.vcc b/src/variable.vcc
index 7a3151f..b2888fa 100644
--- a/src/variable.vcc
+++ b/src/variable.vcc
@@ -1,3 +1,3 @@
# This file is part of vmod-variable
-# Copyright (C) 2015 Sergey Poznyakoff
+# Copyright (C) 2015, 2016 Sergey Poznyakoff
#
diff --git a/tests/Makefile.am b/tests/Makefile.am
index 594b1f5..2d5a2d6 100644
--- a/tests/Makefile.am
+++ b/tests/Makefile.am
@@ -62,13 +62,13 @@ AUTOTEST = $(AUTOM4TE) --language=autotest
$(TESTSUITE): package.m4 $(TESTSUITE_AT)
- $(AUTOTEST) -I $(srcdir) testsuite.at -o $@.tmp
- mv $@.tmp $@
+ $(AM_V_GEN)$(AUTOTEST) -I $(srcdir) testsuite.at -o $@.tmp
+ $(AM_V_at)mv $@.tmp $@
atconfig: $(top_builddir)/config.status
- cd $(top_builddir) && ./config.status tests/$@
+ @cd $(top_builddir) && ./config.status tests/$@
clean-local:
- test ! -f $(TESTSUITE) || $(SHELL) $(TESTSUITE) --clean
+ @test ! -f $(TESTSUITE) || $(SHELL) $(TESTSUITE) --clean
check-local: atconfig atlocal $(TESTSUITE)
- $(SHELL) $(TESTSUITE)
+ @$(SHELL) $(TESTSUITE)

Return to:

Send suggestions and report system problems to the System administrator.
diff --git a/src/variable.c b/src/variable.c
index d9030a3..333daeb 100644
--- a/src/variable.c
+++ b/src/variable.c
@@ -1,5 +1,5 @@
-/* This file is part of vmod-tbf
- Copyright (C) 2013-2015 Sergey Poznyakoff
+/* This file is part of vmod-variable
+ Copyright (C) 2013-2016 Sergey Poznyakoff
- Vmod-tbf is free software; you can redistribute it and/or modify
+ Vmod-variable is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
@@ -8,3 +8,3 @@
- Vmod-tbf is distributed in the hope that it will be useful,
+ Vmod-variable is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,3 +14,3 @@
You should have received a copy of the GNU General Public License
- along with vmod-tbf. If not, see <http://www.gnu.org/licenses/>.
+ along with vmod-variable. If not, see <http://www.gnu.org/licenses/>.
*/